'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = FieldsOnCorrectType;

var _error = require('../../error');

var _errors = require('../errors');

/**
 * Fields on correct type
 *
 * A GraphQL document is only valid if all fields selected are defined by the
 * parent type, or are an allowed meta field such as __typenamme
 */

function FieldsOnCorrectType(context) {
  return {
    Field: function Field(node) {
      var type = context.getParentType();
      if (type) {
        var fieldDef = context.getFieldDef();
        if (!fieldDef) {
          return new _error.GraphQLError((0, _errors.undefinedFieldMessage)(node.name.value, type.name), [node]);
        }
      }
    }
  };
}

module.exports = exports['default'];

/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 *  This source code is licensed under the BSD-style license found in the
 *  LICENSE file in the root directory of this source tree. An additional grant
 *  of patent rights can be found in the PATENTS file in the same directory.
 */