'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
exports['default'] = VariablesAreInputTypes;

var _error = require('../../error');

var _languagePrinter = require('../../language/printer');

var _languageKinds = require('../../language/kinds');

var _typeDefinition = require('../../type/definition');

var _errors = require('../errors');

/**
 * Variables are input types
 *
 * A GraphQL operation is only valid if all the variables it defines are of
 * input types (scalar, enum, or input object).
 */

function VariablesAreInputTypes(context) {
  return {
    VariableDefinition: function VariableDefinition(node) {
      // Get the un-modified type from the variable definition, unwrapping
      // List and NonNull.
      var typeAST = node.type;
      while (typeAST.kind !== _languageKinds.NAME) {
        typeAST = typeAST.type;
      }

      // Get the type definition from the Schema.
      var typeDef = context.getSchema().getType(typeAST.value);

      // If the variable type is not an input type, return an error.
      if (!(0, _typeDefinition.isInputType)(typeDef)) {
        var variableName = node.variable.name.value;
        return new _error.GraphQLError((0, _errors.nonInputTypeOnVarMessage)(variableName, (0, _languagePrinter.print)(node.type)), [node.type]);
      }
    }
  };
}

module.exports = exports['default'];

/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 *  This source code is licensed under the BSD-style license found in the
 *  LICENSE file in the root directory of this source tree. An additional grant
 *  of patent rights can be found in the PATENTS file in the same directory.
 */